@@ -1,6 +1,6 @@
-/* utimecmp.h -- compare file time stamps
+/* utimecmp.h -- compare file timestamps
 
-   Copyright (C) 2004, 2009-2015 Free Software Foundation, Inc.
+   Copyright (C) 2004, 2009-2020 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -13,7 +13,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */
 
 /* Written by Paul Eggert.  */
 
@@ -26,12 +26,14 @@
 /* Options for utimecmp.  */
 enum
 {
-  /* Before comparing, truncate the source time stamp to the
+  /* Before comparing, truncate the source timestamp to the
      resolution of the destination file system and to the resolution
      of utimens.  */
   UTIMECMP_TRUNCATE_SOURCE = 1
 };
 
 int utimecmp (char const *, struct stat const *, struct stat const *, int);
+int utimecmpat (int, char const *, struct stat const *, struct stat const *,
+                int);
 
 #endif
